==> minecraft_python-0.31.20091231.post2-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: mc/net/minecraft/game/level/MobSpawner.py <==
from mc.net.minecraft.game.level.material.Material import Material
from mc.net.minecraft.game.entity.EntityLiving import EntityLiving
from mc.net.minecraft.game.entity.AILiving import AILiving

import math

class MobSpawner:

    def __init__(self, world):
        self.__worldObj = world

    def spawn(self):
        size = self.__worldObj.width * self.__worldObj.length * self.__worldObj.height // 64 // 64 // 64
        if math.floor(self.__worldObj.rand.random() * 100) < size and \
           self.__worldObj.entitiesInLevelList(EntityLiving) < size * 20:
            self.performSpawning(size, self.__worldObj.playerEntity, None)

    def performSpawning(self, count, entity, loader):
        mobs = 0
        for i in range(count):
            math.floor(self.__worldObj.rand.random() * 5)
            blockX = math.floor(self.__worldObj.rand.random() * self.__worldObj.width)
            blockY = int(min(self.__worldObj.rand.random(), self.__worldObj.rand.random()) * self.__worldObj.height)
            blockZ = math.floor(self.__worldObj.rand.random() * self.__worldObj.length)
            if not self.__worldObj.isBlockNormalCube(blockX, blockY, blockZ) and \
               self.__worldObj.getBlockMaterial(blockX, blockY, blockZ) == Material.air and \
               (not self.__worldObj.isHalfLit(blockX, blockY, blockZ) or \
               math.floor(self.__worldObj.rand.random() * 5) == 0):
                for j in range(3):
                    xx = blockX
                    yy = blockY
                    zz = blockZ
                    for k in range(3):
                        xx += math.floor(self.__worldObj.rand.random() * 6) - math.floor(self.__worldObj.rand.random() * 6)
                        yy += math.floor(self.__worldObj.rand.random() * 1) - math.floor(self.__worldObj.rand.random() * 1)
                        zz += math.floor(self.__worldObj.rand.random() * 6) - math.floor(self.__worldObj.rand.random() * 6)
                        if xx >= 0 and zz >= 1 and yy >= 0 and \
                           yy < self.__worldObj.height - 2 and xx < self.__worldObj.width and zz < self.__worldObj.length and \
                           self.__worldObj.isBlockNormalCube(xx, yy - 1, zz) and not \
                           self.__worldObj.isBlockNormalCube(xx, yy, zz) and not \
                           self.__worldObj.isBlockNormalCube(xx, yy + 1, zz):
                            x = xx + 0.5
                            y = yy + 1.0
                            z = zz + 0.5
                            if entity:
                                xd = x - entity.posX
                                yd = y - entity.posY
                                zd = z - entity.posZ
                                if xd * xd + yd * yd + zd * zd < 256.0:
                                    continue
                            else:
                                xd = x - self.__worldObj.xSpawn
                                yd = y - self.__worldObj.ySpawn
                                zd = z - self.__worldObj.zSpawn
                                if xd * xd + yd * yd + zd * zd < 256.0:
                                    continue

                            mob = EntityLiving(self.__worldObj)
                            mob.prevPosX = mob.posX = x
                            mob.prevPosY = mob.posY = y
                            mob.prevPosZ = mob.posZ = z
                            mob.rotationYaw = self.__worldObj.rand.random() * 360.0
                            mob.rotationPitch = 0.0
                            mob.setPosition(x, y, z)
                            mob.entityAI = AILiving()
                            if self.__worldObj.checkIfAABBIsClear(mob.boundingBox):
                                mobs += 1
                                self.__worldObj.spawnEntityInWorld(mob)

        return mobs

==> minecraft_python-0.31.20100110-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: mc/net/minecraft/game/level/MobSpawner.py <==
from mc.net.minecraft.game.level.material.Material import Material
from mc.net.minecraft.game.entity.EntityLiving import EntityLiving
from mc.net.minecraft.game.entity.AILiving import AILiving

import random
import math

class MobSpawner:

    def __init__(self, world):
        self.__worldObj = world

    def spawn(self):
        size = self.__worldObj.width * self.__worldObj.length * self.__worldObj.height // 64 // 64 // 64
        if math.floor(random.random() * 100) < size and \
           self.__worldObj.entitiesInLevelList(EntityLiving) < size * 20:
            self.performSpawning(size, self.__worldObj.playerEntity, None)

    def performSpawning(self, count, entity, loader):
        mobs = 0
        for i in range(count):
            math.floor(random.random() * 5)
            blockX = math.floor(random.random() * self.__worldObj.width)
            blockY = int(min(random.random(), random.random()) * self.__worldObj.height)
            blockZ = math.floor(random.random() * self.__worldObj.length)
            if not self.__worldObj.isBlockNormalCube(blockX, blockY, blockZ) and \
               self.__worldObj.getBlockMaterial(blockX, blockY, blockZ) == Material.air and \
               (not self.__worldObj.isHalfLit(blockX, blockY, blockZ) or \
                math.floor(random.random() * 5) == 0):
                for j in range(8):
                    xx = blockX
                    yy = blockY
                    zz = blockZ
                    for k in range(3):
                        xx += math.floor(random.random() * 6) - math.floor(random.random() * 6)
                        yy += math.floor(random.random() * 1) - math.floor(random.random() * 1)
                        zz += math.floor(random.random() * 6) - math.floor(random.random() * 6)
                        if xx >= 0 and zz >= 0 and yy >= 0 and \
                           yy < self.__worldObj.height - 2 and xx < self.__worldObj.width and zz < self.__worldObj.length and \
                           self.__worldObj.isBlockNormalCube(xx, yy - 1, zz) and not \
                           self.__worldObj.isBlockNormalCube(xx, yy, zz) and not \
                           self.__worldObj.isBlockNormalCube(xx, yy + 1, zz):
                            x = xx + 0.5
                            y = yy + 1.0
                            z = zz + 0.5
                            if entity:
                                xd = x - entity.posX
                                yd = y - entity.posY
                                zd = z - entity.posZ
                            else:
                                xd = x - self.__worldObj.xSpawn
                                yd = y - self.__worldObj.ySpawn
                                zd = z - self.__worldObj.zSpawn

                            if xd * xd + yd * yd + zd * zd < 256.0:
                                continue

                            mob = EntityLiving(self.__worldObj)
                            yaw = random.random() * 360.0
                            mob.setPositionAndRotation(x, y, z, yaw, 0.0)
                            mob.setEntityAI(AILiving())
                            if self.__worldObj.checkIfAABBIsClear(mob.boundingBox):
                                mobs += 1
                                self.__worldObj.releaseEntitySkin(mob)

        return mobs
